# FindYourProfessor

A python based web scraper tool to extract emails of professors matching with keywords representing professors field of interest. It takes in the faculty directory url of a university and the keywords as input and returns the name, email and webpage of the professors with matching research interest.

## Inputs
Provide the webpage URL from where you wish to find details about professors, along with the keywords.

## Installation

```bash
pip install FindYourProfessor

